anthropicprovider

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 1, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Overview

Package anthropicprovider provides Anthropic (Claude)-backed agents via NewAgent, which takes an Anthropic client and an AgentConfig.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MessageNewParams

func MessageNewParams(params anthropic.MessageNewParams) agent.Option

MessageNewParams allows passing custom parameters to the underlying anthropic API calls.

func NewAgent

func NewAgent(aclient anthropic.Client, config AgentConfig) *agent.Agent

NewAgent creates a new agent.Agent backed by the Anthropic Messages API via the anthropic client.

Types

type AgentConfig

type AgentConfig struct {
	agent.Config

	// ToolAutoCall configures automatic function-tool invocation. When nil, defaults
	// are used.
	ToolAutoCall *toolautocall.Config

	// Instructions are provided to Anthropic as system instructions for each run.
	Instructions string

	Model string
}

AgentConfig contains configuration for NewAgent.

Jump to